Struct SessionLock
pub struct SessionLock(/* private fields */);Available on crate feature
wayland and Linux only.Expand description
A session lock
Once a lock is created, you must wait for either a locked or finished event before
destroying this object. If you get a locked event, you must explicitly call unlock prior
to dropping this object.
Implementations
impl SessionLock
impl SessionLock
pub fn from_ext_session_lock(surface: &ExtSessionLockV1) -> Option<SessionLock>
pub fn is_locked(&self) -> bool
pub fn unlock(&self)
impl SessionLock
impl SessionLock
pub fn create_lock_surface<D>( &self, surface: impl Into<Surface>, output: &WlOutput, qh: &QueueHandle<D>, ) -> SessionLockSurface