Trait SessionLockHandler

pub trait SessionLockHandler: Sized {
    // Required methods
    fn locked(
        &mut self,
        conn: &Connection,
        qh: &QueueHandle<Self>,
        session_lock: SessionLock,
    );
    fn finished(
        &mut self,
        conn: &Connection,
        qh: &QueueHandle<Self>,
        session_lock: SessionLock,
    );
    fn configure(
        &mut self,
        conn: &Connection,
        qh: &QueueHandle<Self>,
        surface: SessionLockSurface,
        configure: SessionLockSurfaceConfigure,
        serial: u32,
    );
}
Available on crate feature wayland and Linux only.
Handler trait for session lock protocol.

Required Methods

fn locked( &mut self, conn: &Connection, qh: &QueueHandle<Self>, session_lock: SessionLock, )

The session lock is active, and the client may create lock surfaces.

fn finished( &mut self, conn: &Connection, qh: &QueueHandle<Self>, session_lock: SessionLock, )

Session lock is not active and should be destroyed.

This may be sent immediately if the compositor denys the requires to create a lock, or may be sent some time after lock.

fn configure( &mut self, conn: &Connection, qh: &QueueHandle<Self>, surface: SessionLockSurface, configure: SessionLockSurfaceConfigure, serial: u32, )

Compositor has requested size for surface.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors